@@ -5,36 +5,28 @@
 **
 ** This file is part of the QtSensors module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
+** a written agreement between you and Digia. For licensing terms and
+** conditions see http://qt.digia.com/licensing. For further information
 ** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** rights. These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -44,7 +36,9 @@
 #include <qsensorbackend.h>
 #include <qsensormanager.h>
 #include <qaccelerometer.h>
+#include <qcompass.h>
 #include "androidaccelerometer.h"
+#include "androidcompass.h"
 #include "androidgyroscope.h"
 #include "androidlight.h"
 #include "androidmagnetometer.h"
@@ -63,10 +57,13 @@ class AndroidSensorPlugin : public QObject, public QSensorPluginInterface, publi
 public:
     void registerSensors()
     {
+        bool accelerometer = false;
+        bool magnetometer = false;
         foreach (AndroidSensorType sensor, availableSensors()) {
             switch (sensor) {
             case TYPE_ACCELEROMETER:
                 QSensorManager::registerBackend(QAccelerometer::type, QByteArray::number(sensor), this);
+                accelerometer = true;
                 break;
             case TYPE_AMBIENT_TEMPERATURE:
             case TYPE_TEMPERATURE:
@@ -84,6 +81,7 @@ public:
                 break; // add the linear acceleration sensor backend
             case TYPE_MAGNETIC_FIELD:
                 QSensorManager::registerBackend(QMagnetometer::type, QByteArray::number(sensor), this);
+                magnetometer = true;
                 break;
             case TYPE_ORIENTATION:
                 break; // add the orientation sensor backend
@@ -106,10 +104,15 @@ public:
                 break; // add backends for API level 18 sensors
             }
         }
+        if (accelerometer && magnetometer)
+            QSensorManager::registerBackend(QCompass::type, AndroidCompass::id, this);
     }
 
     QSensorBackend *createBackend(QSensor *sensor)
     {
+        if (sensor->identifier() == AndroidCompass::id)
+            return new AndroidCompass(sensor);
+
         AndroidSensorType type = static_cast<AndroidSensorType>(sensor->identifier().toInt());
         switch (type) {
         case TYPE_ACCELEROMETER: {
