@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the QtSensors module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
+** a written agreement between you and Digia. For licensing terms and
+** conditions see http://qt.digia.com/licensing. For further information
 ** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** rights. These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -42,12 +34,12 @@
 #include "sensorfwproximitysensor.h"
 
 char const * const SensorfwProximitySensor::id("sensorfw.proximitysensor");
-//bool SensorfwProximitySensor::m_initDone = false;
 
 SensorfwProximitySensor::SensorfwProximitySensor(QSensor *sensor)
     : SensorfwSensorBase(sensor),
-      m_exClose(false)
-    , m_initDone(false)
+      m_initDone(false),
+      m_exClose(false),
+      firstRun(true)
 {
     init();
     setReading<QProximityReading>(&m_reading);
@@ -57,12 +49,8 @@ SensorfwProximitySensor::SensorfwProximitySensor(QSensor *sensor)
 
 void SensorfwProximitySensor::start()
 {
-    if (m_sensorInterface) {
-        Unsigned data(((ProximitySensorChannelInterface*)m_sensorInterface)->proximity());
-        m_reading.setClose(data.x()? true: false);
-        m_reading.setTimestamp(data.UnsignedData().timestamp_);
-        newReadingAvailable();
-    }
+    if (reinitIsNeeded)
+        init();
     SensorfwSensorBase::start();
 }
 
@@ -70,15 +58,18 @@ void SensorfwProximitySensor::start()
 void SensorfwProximitySensor::slotDataAvailable(const Unsigned& data)
 {
     bool close = data.x()? true: false;
-    if (close == m_exClose) return;
+    if (!firstRun && close == m_exClose) return;
     m_reading.setClose(close);
     m_reading.setTimestamp(data.UnsignedData().timestamp_);
     newReadingAvailable();
     m_exClose = close;
+    if (firstRun)
+        firstRun = false;
 }
 
 bool SensorfwProximitySensor::doConnect()
 {
+    Q_ASSERT(m_sensorInterface);
     return (QObject::connect(m_sensorInterface, SIGNAL(dataAvailable(Unsigned)),
                              this, SLOT(slotDataAvailable(Unsigned))));
 }
