@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the QtSensors module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
+** a written agreement between you and Digia. For licensing terms and
+** conditions see http://qt.digia.com/licensing. For further information
 ** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** rights. These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -52,6 +44,7 @@ QT_BEGIN_NAMESPACE
 /*!
     \typedef qrange
     \relates QSensor
+    \since 5.1
 
     This type is defined as a QPair.
 
@@ -65,6 +58,7 @@ QT_BEGIN_NAMESPACE
 /*!
     \typedef qrangelist
     \relates QSensor
+    \since 5.1
 
     This type is defined as a list of qrange values.
 
@@ -80,6 +74,7 @@ QT_BEGIN_NAMESPACE
     \relates QSensor
     \inmodule QtSensors
     \brief The qoutputrange class holds the specifics of an output range.
+    \since 5.1
 
     The class is defined as a simple struct.
 
@@ -133,6 +128,7 @@ QT_BEGIN_NAMESPACE
 /*!
     \typedef qoutputrangelist
     \relates QSensor
+    \since 5.1
 
     This type is defined as a list of qoutputrange values.
 
@@ -164,6 +160,7 @@ void QSensorPrivate::init(const QByteArray &sensorType)
     \class QSensor
     \ingroup sensors_main
     \inmodule QtSensors
+    \since 5.1
 
     \brief The QSensor class represents a single hardware sensor.
 
